/**
 * MEDOR: Middleware Enabling Distributed Object Requests
 *
 * Copyright (C) 2001-2003 France Telecom R&D
 * Contact: alexandre.lefebvre@rd.francetelecom.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Initial developers: M. Alia, S. Chassande-Barrioz, A. Lefebvre
 */

package org.objectweb.medor.filter.lib;

import org.objectweb.medor.filter.api.Operator;
import org.objectweb.medor.filter.api.ParameterOperand;
import org.objectweb.medor.filter.api.Expression;
import org.objectweb.medor.api.TypingException;
import org.objectweb.medor.api.MalformedExpressionException;
import org.objectweb.medor.api.MedorException;
import org.objectweb.medor.api.EvaluationException;
import org.objectweb.medor.tuple.api.Tuple;

/**
 * Max aggregate function.
 * <p> Max applies to :
 * <ol>
 * <li>a FieldOperand, which is part of a NestedField.</li>
 * <li>a Collection of values (TupleCollection), specifying which Field
 * is to be aggregated</li>
 * <li>a Collection of values (Java Collection)</li>
 * </ol>
 * @author Alexandre Lefebvre
 */
public class Max extends BasicAggregateOperator {

	public Max(Expression e) {
		this.operand = e;
	}

	public Max(Expression e, boolean distinct) {
		this.operand = e;
		this.distinct = distinct;
	}

	public String getOperatorString() {
		return Operator.MAX;
	}

	public void compileExpression()
			throws TypingException, MalformedExpressionException {
		if (operand != null) {
			operand.compileExpression();
				result = new BasicVariableOperand(operand.getType());
				verified = true;
		}
		else
		// Operands not yet assigned
			throw new MalformedExpressionException("null children value");
	}

	public void evaluate(ParameterOperand[] pos, Tuple t)
			throws MedorException {
		throw new EvaluationException("Implementation of Avg by MEDOR not yet implemented");
	}
}
